Crate rustdoc_ext

Crate rustdoc_ext 

Extension traits for types in rustdoc_types.

This crate provides utility traits that augment the types from our fork of rustdoc-types. We keep these extensions separate to maintain rustdoc_types as close to upstream as possible.

Structs

GlobalItemId
An identifier that unequivocally points to a type within a crate collection.

Traits

ItemKindExt
Extension trait for ItemKind to get human-readable descriptions.
RustdocKindExt
Extension trait for ItemEnum to get a human-readable description of the item kind.