Extension traits for types in rustdoc_types.
This crate provides utility traits that augment the types from our fork of rustdoc-types.
We keep these extensions separate to maintain rustdoc_types as close to upstream
as possible.
Structs
- Global
Item Id - An identifier that unequivocally points to a type within a crate collection.
Traits
- Item
Kind Ext - Extension trait for
ItemKindto get human-readable descriptions. - Rustdoc
Kind Ext - Extension trait for
ItemEnumto get a human-readable description of the item kind.